ui

package
v0.0.0-...-f0976ba Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DefaultItemStyles

type DefaultItemStyles struct {
	// The Normal state.
	NormalTitle lipgloss.Style
	NormalDesc  lipgloss.Style

	// The selected item state.
	SelectedTitle lipgloss.Style
	SelectedDesc  lipgloss.Style

	// The dimmed state, for when the filter input is initially activated.
	DimmedTitle lipgloss.Style
	DimmedDesc  lipgloss.Style

	// Characters matching the current filter, if any.
	FilterMatch lipgloss.Style
}

func NewDefaultItemStyles

func NewDefaultItemStyles() (s DefaultItemStyles)

type Model

type Model struct {
	Player  *audio.Player
	Library *audio.Library
	// contains filtered or unexported fields
}

func InitialModel

func InitialModel(config config.Config) (Model, error)

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) ListenForUpdates

func (m Model) ListenForUpdates() tea.Cmd

Waits for messages from the player about any type of update

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

Jump to